import typing
import collections.abc
import typing_extensions
import numpy.typing as npt

class NodeEditorBase:
    @classmethod
    def poll(cls, context):
        """

        :param context:
        """

def force_update(context): ...
def get_group_output_node(tree, output_node_idname="NodeGroupOutput"): ...
def get_internal_socket(socket): ...
def get_output_location(tree): ...
def is_viewer_link(link, output_node): ...
def is_visible_socket(socket): ...
def node_editor_poll(cls, context): ...
def node_space_type_poll(cls, context, types): ...
